==> ibiz-model-8.1.0.304-sources.jar: net/ibizsys/model/ba/IPSSysBDScheme.java <==
package net.ibizsys.model.ba;



/**
 *
 */
public interface IPSSysBDScheme extends net.ibizsys.model.ba.IPSBDScheme{

	
	
	/**
	 * 获取大数据体系模块集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDModule> getAllPSSysBDModules();
	
	/**
	 * 获取大数据体系模块集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDModule getPSSysBDModule(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据体系模块集合
	 * @param list 大数据体系模块集合
	 */
	void setPSSysBDModules(java.util.List<net.ibizsys.model.ba.IPSSysBDModule> list);
	
	
	/**
	 * 获取大数据体系分区集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDPart> getAllPSSysBDParts();
	
	/**
	 * 获取大数据体系分区集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDPart getPSSysBDPart(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据体系分区集合
	 * @param list 大数据体系分区集合
	 */
	void setPSSysBDParts(java.util.List<net.ibizsys.model.ba.IPSSysBDPart> list);
	
	
	/**
	 * 获取大数据表关系集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDTableRS> getAllPSSysBDTableRSs();
	
	/**
	 * 获取大数据表关系集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDTableRS getPSSysBDTableRS(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据表关系集合
	 * @param list 大数据表关系集合
	 */
	void setPSSysBDTableRs(java.util.List<net.ibizsys.model.ba.IPSSysBDTableRS> list);
	
	
	/**
	 * 获取大数据表集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDTable> getAllPSSysBDTables();
	
	/**
	 * 获取大数据表集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDTable getPSSysBDTable(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据表集合
	 * @param list 大数据表集合
	 */
	void setPSSysBDTables(java.util.List<net.ibizsys.model.ba.IPSSysBDTable> list);
	
	
	/**
	 * 获取认证客户端标识
	 * @return
	 */
	java.lang.String getAuthClientId();
	
	
	/**
	 * 获取认证客户端密码
	 * @return
	 */
	java.lang.String getAuthClientSecret();
	
	
	/**
	 * 获取认证模式
	 * <P>
	 * 返回值参考 {@link net.ibizsys.model.PSModelEnums.APIAuthMode}
	 * @return
	 */
	java.lang.String getAuthMode();
	
	
	/**
	 * 获取认证参数
	 * @return
	 */
	java.lang.String getAuthParam();
	
	
	/**
	 * 获取认证参数2
	 * @return
	 */
	java.lang.String getAuthParam2();
	
	
	/**
	 * 获取系统模型组
	 * @return
	 */
	net.ibizsys.model.system.IPSSysModelGroup getPSSysModelGroup();


	/**
	 * 获取系统模型组，不存在时抛出异常
	 * @return
	 */
	net.ibizsys.model.system.IPSSysModelGroup getPSSysModelGroupMust();
	
	
	/**
	 * 获取后台扩展插件
	 * @return
	 */
	net.ibizsys.model.res.IPSSysSFPlugin getPSSysSFPlugin();


	/**
	 * 获取后台扩展插件，不存在时抛出异常
	 * @return
	 */
	net.ibizsys.model.res.IPSSysSFPlugin getPSSysSFPluginMust();
	
	
	/**
	 * 获取系统模块
	 * @return
	 */
	net.ibizsys.model.system.IPSSystemModule getPSSystemModule();


	/**
	 * 获取系统模块，不存在时抛出异常
	 * @return
	 */
	net.ibizsys.model.system.IPSSystemModule getPSSystemModuleMust();
	
	
	/**
	 * 获取服务参数
	 * @return
	 */
	java.lang.String getServiceParam();
	
	
	/**
	 * 获取服务参数2
	 * @return
	 */
	java.lang.String getServiceParam2();
	
	
	/**
	 * 获取服务路径
	 * @return
	 */
	java.lang.String getServicePath();
	
	
	/**
	 * 获取是否默认大数据体系
	 * @return
	 */
	boolean isDefaultMode();
}

==> ibiz-model-8.1.0.516-sources.jar: net/ibizsys/model/ba/IPSSysBDScheme.java <==
package net.ibizsys.model.ba;



/**
 *
 */
public interface IPSSysBDScheme extends net.ibizsys.model.ba.IPSBDScheme
		,net.ibizsys.model.service.IPSSubSysServiceAPIBase{

	
	
	/**
	 * 获取大数据体系模块集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDModule> getAllPSSysBDModules();
	
	/**
	 * 获取大数据体系模块集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDModule getPSSysBDModule(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据体系模块集合
	 * @param list 大数据体系模块集合
	 */
	void setPSSysBDModules(java.util.List<net.ibizsys.model.ba.IPSSysBDModule> list);
	
	
	/**
	 * 获取大数据体系分区集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDPart> getAllPSSysBDParts();
	
	/**
	 * 获取大数据体系分区集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDPart getPSSysBDPart(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据体系分区集合
	 * @param list 大数据体系分区集合
	 */
	void setPSSysBDParts(java.util.List<net.ibizsys.model.ba.IPSSysBDPart> list);
	
	
	/**
	 * 获取大数据表关系集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDTableRS> getAllPSSysBDTableRSs();
	
	/**
	 * 获取大数据表关系集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDTableRS getPSSysBDTableRS(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据表关系集合
	 * @param list 大数据表关系集合
	 */
	void setPSSysBDTableRs(java.util.List<net.ibizsys.model.ba.IPSSysBDTableRS> list);
	
	
	/**
	 * 获取大数据表集合
	 * @return
	 */
	java.util.List<net.ibizsys.model.ba.IPSSysBDTable> getAllPSSysBDTables();
	
	/**
	 * 获取大数据表集合的指定项
	 * @param objKey 项标识
	 * @param bTryMode 是否为尝试获取
	 * @return 返回指定项，尝试模式下不存在返回null，否则抛出异常
	 */
	net.ibizsys.model.ba.IPSSysBDTable getPSSysBDTable(Object objKey, boolean bTryMode);
	
	/**
	 * 设置大数据表集合
	 * @param list 大数据表集合
	 */
	void setPSSysBDTables(java.util.List<net.ibizsys.model.ba.IPSSysBDTable> list);
	
	
	/**
	 * 获取认证客户端标识
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_AUTHCLIENTID}
	 * @return
	 */
	java.lang.String getAuthClientId();
	
	
	/**
	 * 获取认证客户端密码
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_AUTHCLIENTSECRET}
	 * @return
	 */
	java.lang.String getAuthClientSecret();
	
	
	/**
	 * 获取认证模式
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_AUTHMODE}
	 * <P>
	 * 返回值参考 {@link net.ibizsys.model.PSModelEnums.APIAuthMode}
	 * @return
	 */
	java.lang.String getAuthMode();
	
	
	/**
	 * 获取认证参数
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_AUTHPARAM}
	 * @return
	 */
	java.lang.String getAuthParam();
	
	
	/**
	 * 获取认证参数2
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_AUTHPARAM2}
	 * @return
	 */
	java.lang.String getAuthParam2();
	
	
	/**
	 * 获取对象名称转化
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_OBJNAMECASE}
	 * <P>
	 * 返回值参考 {@link net.ibizsys.model.PSModelEnums.DBObjNameCaseMode}
	 * @return
	 */
	java.lang.String getDBObjNameCase();
	
	
	/**
	 * 获取系统模型组
	 * @return
	 */
	net.ibizsys.model.system.IPSSysModelGroup getPSSysModelGroup();


	/**
	 * 获取系统模型组，不存在时抛出异常
	 * @return
	 */
	net.ibizsys.model.system.IPSSysModelGroup getPSSysModelGroupMust();
	
	
	/**
	 * 获取后台扩展插件
	 * @return
	 */
	net.ibizsys.model.res.IPSSysSFPlugin getPSSysSFPlugin();


	/**
	 * 获取后台扩展插件，不存在时抛出异常
	 * @return
	 */
	net.ibizsys.model.res.IPSSysSFPlugin getPSSysSFPluginMust();
	
	
	/**
	 * 获取系统模块
	 * @return
	 */
	net.ibizsys.model.system.IPSSystemModule getPSSystemModule();


	/**
	 * 获取系统模块，不存在时抛出异常
	 * @return
	 */
	net.ibizsys.model.system.IPSSystemModule getPSSystemModuleMust();
	
	
	/**
	 * 获取服务参数
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_SERVICEPARAM}
	 * @return
	 */
	java.lang.String getServiceParam();
	
	
	/**
	 * 获取服务参数2
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_SERVICEPARAM2}
	 * @return
	 */
	java.lang.String getServiceParam2();
	
	
	/**
	 * 获取服务路径
	 * <P>
	 * 相关模型：{@link net.ibizsys.centralstudio.dto.DTO#FIELD_SERVICEPATH}
	 * @return
	 */
	java.lang.String getServicePath();
	
	
	/**
	 * 获取是否默认大数据体系
	 * @return
	 */
	boolean isDefaultMode();
}
